@@ -33,14 +33,17 @@ from ._exceptions import (
     StaticValueException,
     WebsiteNotImplementedError,
 )
-from ._factory import SchemaScraperFactory
 from ._utils import get_host_name
+from ._factory import SchemaScraperFactory
 from .abeautifulmess import ABeautifulMess
 from .aberlehome import AberleHome
 from .abril import Abril
 from .abuelascounter import AbuelasCounter
 from .acouplecooks import ACoupleCooks
+from .acozykitchen import ACozyKitchen
 from .addapinch import AddAPinch
+from .adozensundays import ADozenSundays
+from .afarmgirlsdabbles import AFarmGirlsDabbles
 from .afghankitchenrecipes import AfghanKitchenRecipes
 from .aflavorjournal import AFlavorJournal
 from .ahealthysliceoflife import AHealthySliceOfLife
@@ -54,7 +57,7 @@ from .alexandracooks import AlexandraCooks
 from .alittlebityummy import ALittleBitYummy
 from .allrecipes import AllRecipes
 from .allthehealthythings import AllTheHealthyThings
-from .alltomat import AllTomat
+from .alltommat import AlltOmMat
 from .altonbrown import AltonBrown
 from .amazingoriental import AmazingOriental
 from .amazingribs import AmazingRibs
@@ -67,6 +70,7 @@ from .arla import Arla
 from .atelierdeschefs import AtelierDesChefs
 from .averiecooks import AverieCooks
 from .bakels import Bakels
+from .bakerbynature import BakerByNature
 from .bakewithzoha import BakeWithZoha
 from .bakingmischief import BakingMischief
 from .bakingsense import BakingSense
@@ -101,14 +105,15 @@ from .carlsbadcravings import CarlsBadCravings
 from .castironketo import CastIronKeto
 from .cdkitchen import CdKitchen
 from .celebratingsweets import CelebratingSweets
+from .chefjackovens import ChefJackOvens
 from .chefjeanpierre import ChefJeanPierre
 from .chefkoch import Chefkoch
 from .chefnini import Chefnini
 from .chefsavvy import ChefSavvy
+from .chewoutloud import ChewOutLoud
 from .closetcooking import ClosetCooking
 from .colleenchristensennutrition import ColleenChristensenNutrition
 from .comidinhasdochef import ComidinhasDoChef
-from .cookeatshare import CookEatShare
 from .cookieandkate import CookieAndKate
 from .cookiesandcups import CookiesAndCups
 from .cookingcircle import CookingCircle
@@ -122,6 +127,7 @@ from .cooksillustrated import CooksIllustrated
 from .cooktalk import CookTalk
 from .cookwell import CookWell
 from .copykat import CopyKat
+from .corriecooks import CorrieCooks
 from .costco import Costco
 from .countryliving import CountryLiving
 from .creativecanning import CreativeCanning
@@ -141,6 +147,7 @@ from .domesticateme import DomesticateMe
 from .donalskehan import DonalSkehan
 from .downshiftology import Downshiftology
 from .dr import Dr
+from .drizzleanddip import DrizzleAndDip
 from .eatingbirdfood import EatingBirdFood
 from .eatingwell import EatingWell
 from .eatliverun import EatLiveRun
@@ -157,6 +164,7 @@ from .epicurious import Epicurious
 from .erinliveswhole import ErinLivesWhole
 from .errenskitchen import ErrensKitchen
 from .ethanchlebowski import EthanChlebowski
+from .everydaypie import EverydayPie
 from .evolvingtable import EvolvingTable
 from .familyfoodonthetable import FamilyfoodOnTheTable
 from .farmhousedelivery import FarmhouseDelivery
@@ -205,9 +213,12 @@ from .heatherchristo import HeatherChristo
 from .heb import HEB
 from .hellofresh import HelloFresh
 from .hersheyland import HersheyLand
+from .hilahcooking import HilahCooking
 from .hofer import Hofer
+from .homeandplate import HomeAndPlate
 from .homechef import HomeChef
 from .hostthetoast import Hostthetoast
+from .howtofeedaloon import HowToFeedALoon
 from .hungryhappens import HungryHappens
 from .ica import Ica
 from .ig import IG
@@ -219,6 +230,7 @@ from .innit import Innit
 from .insanelygoodrecipes import InsanelyGoodRecipes
 from .inspiralized import Inspiralized
 from .inspiredtaste import InspiredTaste
+from .iowagirleats import IowaGirlEats
 from .irishcentral import IrishCentral
 from .izzycooking import IzzyCooking
 from .jamieoliver import JamieOliver
@@ -229,13 +241,17 @@ from .joyfoodsunshine import Joyfoodsunshine
 from .joythebaker import JoyTheBaker
 from .juliegoodwin import JulieGoodwin
 from .jumbo import Jumbo
+from .justalittlebitofbacon import JustALittleBitOfBacon
 from .justataste import JustATaste
 from .justbento import JustBento
+from .justinesnacks import JustineSnacks
 from .justonecookbook import JustOneCookbook
 from .kalejunkie import KaleJunkie
 from .kellyscleankitchen import KellysCleanKitchen
 from .kennymcgovern import KennyMcGovern
 from .keukenliefdenl import KeukenLiefdeNL
+from .kiddokitchen import KiddoKitchen
+from .kikkoman import Kikkoman
 from .kingarthur import KingArthur
 from .kitchenaidaustralia import KitchenAidAustralia
 from .kitchendivas import KitchenDivas
@@ -256,6 +272,7 @@ from .lanascooking import LanasCooking
 from .latelierderoxane import LAtelierDeRoxane
 from .leanandgreenrecipes import LeanAndGreenRecipes
 from .lecker import Lecker
+from .leckerschmecker import LeckerSchmecker
 from .lecremedelacrumb import LeCremeDeLaCrumb
 from .leitesculinaria import LeitesCulinaria
 from .lekkerensimpel import LekkerEnSimpel
@@ -279,6 +296,7 @@ from .mealprepmanual import MealPrepManual
 from .meganvskitchen import MeganVsKitchen
 from .meljoulwan import Meljoulwan
 from .melskitchencafe import MelsKitchenCafe
+from .migusto import Migusto
 from .miljuschka import Miljuschka
 from .mindmegette import Mindmegette
 from .minimalistbaker import Minimalistbaker
@@ -300,10 +318,13 @@ from .mykoreankitchen import MyKoreanKitchen
 from .myrecipes import MyRecipes
 from .myvegetarianroots import MyVegetarianRoots
 from .natashaskitchen import NatashasKitchen
+from .naturallyella import NaturallyElla
 from .ndr import Ndr
+from .netacooks import NetaCooks
 from .nhshealthierfamilies import NHSHealthierFamilies
 from .nibbledish import NibbleDish
 from .nihhealthyeating import NIHHealthyEating
+from .ninjatestkitchen import NinjaTestKitchen
 from .noracooks import NoraCooks
 from .norecipes import NoRecipes
 from .nosalty import NoSalty
@@ -326,15 +347,18 @@ from .owenhan import OwenHan
 from .paleorunningmomma import PaleoRunningMomma
 from .panelinha import Panelinha
 from .paninihappy import PaniniHappy
+from .panlasangpinoy import PanlasangPinoy
 from .peelwithzeal import PeelWithZeal
 from .persnicketyplates import PersnicketyPlates
 from .pickuplimes import PickUpLimes
 from .picnic import Picnic
+from .pilipinasrecipes import PilipinasRecipes
 from .pinchofyum import PinchOfYum
 from .pingodoce import PingoDoce
 from .pinkowlkitchen import PinkOwlKitchen
 from .platingpixels import PlatingPixels
 from .plowingthroughlife import PlowingThroughLife
+from .poppycooks import PoppyCooks
 from .popsugar import PopSugar
 from .potatorolls import PotatoRolls
 from .practicalselfreliance import PracticalSelfReliance
@@ -345,10 +369,12 @@ from .projectgezond import ProjectGezond
 from .przepisy import Przepisy
 from .purelypope import PurelyPope
 from .purplecarrot import PurpleCarrot
+from .quakeroats import QuakerOats
 from .quitoque import QuiToque
 from .rachlmansfield import RachlMansfield
 from .rainbowplantlife import RainbowPlantLife
 from .realfoodtesco import RealFoodTesco
+from .realfoodwell import RealFoodWell
 from .realsimple import RealSimple
 from .receitasnestlebr import ReceitasNestleBR
 from .recept import Recept
@@ -375,6 +401,7 @@ from .sandwhichtribunal import SandwhichTribunal
 from .saveur import Saveur
 from .savorynothings import SavoryNothings
 from .schoolofwok import SchoolOfWok
+from .scrummylane import ScrummyLane
 from .seriouseats import SeriousEats
 from .shelikesfood import SheLikesFood
 from .simplegreensmoothies import SimpleGreenSmoothies
@@ -406,6 +433,7 @@ from .sunset import Sunset
 from .sweetcsdesigns import SweetCsDesigns
 from .sweetpeasandsaffron import SweetPeasAndSaffron
 from .swissmilk import SwissMilk
+from .tableanddish import TableAndDish
 from .tasteatlas import TasteAtlas
 from .tasteau import TasteAU
 from .tasteofhome import TasteOfHome
@@ -415,10 +443,12 @@ from .tastinghistory import TastingHistory
 from .tasty import Tasty
 from .tastykitchen import TastyKitchen
 from .tastyoven import TastyOven
+from .tatyanaseverydayfood import TatyanasEverydayFood
 from .thebigmansworld import TheBigMansWorld
 from .theclevercarrot import TheCleverCarrot
 from .thecookierookie import TheCookieRookie
 from .thecookingguy import TheCookingGuy
+from .thefirstmess import TheFirstMess
 from .thefoodietakesflight import TheFoodieTakesFlight
 from .theglutenfreeaustrian import TheGlutenFreeAustrian
 from .thehappyfoodie import TheHappyFoodie
@@ -429,19 +459,23 @@ from .theloopywhisk import TheLoopyWhisk
 from .themagicalslowcooker import TheMagicalSlowCooker
 from .themediterranedish import TheMediterraneDish
 from .themodernproper import TheModernProper
+from .theoldwomanandthesea import TheOldWomanAndTheSea
 from .thepalatablelife import ThePalatableLife
 from .thepioneerwoman import ThePioneerWoman
 from .theplantbasedschool import ThePlantBasedSchool
 from .therecipecritic import TheRecipeCritic
 from .thesaltymarshmallow import TheSaltyMarshmallow
+from .thespicetrain import TheSpiceTrain
 from .thespruceeats import TheSpruceEats
 from .thevintagemixer import TheVintageMixer
 from .thewoksoflife import Thewoksoflife
 from .thinlicious import Thinlicious
+from .thishealthytable import ThisHealthyTable
 from .tidymom import TidyMom
 from .timesofindia import TimesOfIndia
 from .tineno import TineNo
 from .tofoo import Tofoo
+from .toriavey import ToriAvey
 from .tudogostoso import TudoGostoso
 from .twentyfourkitchen import TwentyFourKitchen
 from .twopeasandtheirpod import TwoPeasAndTheirPod
@@ -471,6 +505,7 @@ from .wikicookbook import WikiCookbook
 from .williamssonoma import WilliamsSonoma
 from .womensweeklyfood import WomensWeeklyFood
 from .woop import Woop
+from .xiachufang import Xiachufang
 from .yemek import Yemek
 from .yummly import Yummly
 from .zaubertopf import ZauberTopf
@@ -480,15 +515,17 @@ from .zestfulkitchen import ZestfulKitchen
 
 SCRAPERS = {
     ABeautifulMess.host(): ABeautifulMess,
-    ACoupleCooks.host(): ACoupleCooks,
-    AFlavorJournal.host(): AFlavorJournal,
-    AHealthySliceOfLife.host(): AHealthySliceOfLife,
-    ALittleBitYummy.host(): ALittleBitYummy,
     AberleHome.host(): AberleHome,
     Abril.host(): Abril,
     AbuelasCounter.host(): AbuelasCounter,
+    ACoupleCooks.host(): ACoupleCooks,
+    ACozyKitchen.host(): ACozyKitchen,
     AddAPinch.host(): AddAPinch,
+    ADozenSundays.host(): ADozenSundays,
+    AFarmGirlsDabbles.host(): AFarmGirlsDabbles,
     AfghanKitchenRecipes.host(): AfghanKitchenRecipes,
+    AFlavorJournal.host(): AFlavorJournal,
+    AHealthySliceOfLife.host(): AHealthySliceOfLife,
     AkisPetretzikis.host(): AkisPetretzikis,
     AlbertHeijn.host(): AlbertHeijn,
     AlbertHeijn.host(domain="ah.be"): AlbertHeijn,
@@ -505,31 +542,33 @@ SCRAPERS = {
     AldiSued.host(domain="aldi.it"): AldiSued,
     AldiSuisse.host(): AldiSuisse,
     AlexandraCooks.host(): AlexandraCooks,
+    ALittleBitYummy.host(): ALittleBitYummy,
     AllRecipes.host(): AllRecipes,
     AllTheHealthyThings.host(): AllTheHealthyThings,
-    AllTomat.host(): AllTomat,
+    AlltOmMat.host(): AlltOmMat,
     AltonBrown.host(): AltonBrown,
     AmazingOriental.host(): AmazingOriental,
     AmazingRibs.host(): AmazingRibs,
     AmbitiousKitchen.host(): AmbitiousKitchen,
-    AmericasTestKitchen.host(): AmericasTestKitchen,
     AmeesSavoryDish.host(): AmeesSavoryDish,
+    AmericasTestKitchen.host(): AmericasTestKitchen,
     ArchanasKitchen.host(): ArchanasKitchen,
     Argiro.host(): Argiro,
     Arla.host(): Arla,
     AtelierDesChefs.host(): AtelierDesChefs,
     AverieCooks.host(): AverieCooks,
+    Bakels.host(): Bakels,
+    Bakels.host(domain="co.uk"): Bakels,
+    BakerByNature.host(): BakerByNature,
+    BakeWithZoha.host(): BakeWithZoha,
+    BakingMischief.host(): BakingMischief,
+    BakingSense.host(): BakingSense,
+    BarefeetInTheKitchen.host(): BarefeetInTheKitchen,
+    BareFootContessa.host(): BareFootContessa,
+    BarefootInThePines.host(): BarefootInThePines,
     BBCFood.host(): BBCFood,
     BBCFood.host(domain="co.uk"): BBCFood,
     BBCGoodFood.host(): BBCGoodFood,
-    BakeWithZoha.host(): BakeWithZoha,
-    Bakels.host(): Bakels,
-    Bakels.host(domain="co.uk"): Bakels,
-    BakingSense.host(): BakingSense,
-    BakingMischief.host(): BakingMischief,
-    BareFootContessa.host(): BareFootContessa,
-    BarefeetInTheKitchen.host(): BarefeetInTheKitchen,
-    BarefootInThePines.host(): BarefootInThePines,
     BestRecipes.host(): BestRecipes,
     BetterFoodGuru.host(): BetterFoodGuru,
     BettyBossi.host(): BettyBossi,
@@ -543,8 +582,8 @@ SCRAPERS = {
     Bodybuilding.host(): Bodybuilding,
     Bofrost.host(): Bofrost,
     BonAppetit.host(): BonAppetit,
-    BowlOfDelicious.host(): BowlOfDelicious,
     BongEats.host(): BongEats,
+    BowlOfDelicious.host(): BowlOfDelicious,
     Breadtopia.host(): Breadtopia,
     BricelEtBaklava.host(): BricelEtBaklava,
     BrokenOvenBaking.host(): BrokenOvenBaking,
@@ -556,27 +595,29 @@ SCRAPERS = {
     CastIronKeto.host(): CastIronKeto,
     CdKitchen.host(): CdKitchen,
     CelebratingSweets.host(): CelebratingSweets,
+    ChefJackOvens.host(): ChefJackOvens,
     ChefJeanPierre.host(): ChefJeanPierre,
-    ChefSavvy.host(): ChefSavvy,
     Chefkoch.host(): Chefkoch,
     Chefnini.host(): Chefnini,
+    ChefSavvy.host(): ChefSavvy,
+    ChewOutLoud.host(): ChewOutLoud,
     ClosetCooking.host(): ClosetCooking,
     ColleenChristensenNutrition.host(): ColleenChristensenNutrition,
     ComidinhasDoChef.host(): ComidinhasDoChef,
-    CookEatShare.host(): CookEatShare,
-    CookPad.host(): CookPad,
-    CookTalk.host(): CookTalk,
-    CookWell.host(): CookWell,
     CookieAndKate.host(): CookieAndKate,
     CookiesAndCups.host(): CookiesAndCups,
     CookingCircle.host(): CookingCircle,
-    CookingLSL.host(): CookingLSL,
     CookingLight.host(): CookingLight,
+    CookingLSL.host(): CookingLSL,
     CookingWithJanica.host(): CookingWithJanica,
     Cookomix.host(): Cookomix,
+    CookPad.host(): CookPad,
     CooksCountry.host(): CooksCountry,
     CooksIllustrated.host(): CooksIllustrated,
+    CookTalk.host(): CookTalk,
+    CookWell.host(): CookWell,
     CopyKat.host(): CopyKat,
+    CorrieCooks.host(): CorrieCooks,
     Costco.host(): Costco,
     CountryLiving.host(): CountryLiving,
     CreativeCanning.host(): CreativeCanning,
@@ -592,131 +633,42 @@ SCRAPERS = {
     DinnerThenDessert.host(): DinnerThenDessert,
     Dishnz.host(): Dishnz,
     DobruChutAktualitySK.host(): DobruChutAktualitySK,
+    DomesticateMe.host(): DomesticateMe,
     DonalSkehan.host(): DonalSkehan,
+    Downshiftology.host(): Downshiftology,
+    Dr.host(): Dr,
+    DrizzleAndDip.host(): DrizzleAndDip,
+    EatingBirdFood.host(): EatingBirdFood,
+    EatingWell.host(): EatingWell,
     EatLiveRun.host(): EatLiveRun,
+    Eatsmarter.host(): Eatsmarter,
+    Eatsmarter.host(domain="de"): Eatsmarter,
     EatThisMuch.host(): EatThisMuch,
+    EatTolerant.host(): EatTolerant,
+    EatWell101.host(): EatWell101,
+    EatWhatTonight.host(): EatWhatTonight,
     EditionsLarousse.host(): EditionsLarousse,
     EggsCa.host(): EggsCa,
     ElaVegan.host(): ElaVegan,
-    ErinLivesWhole.host(): ErinLivesWhole,
-    EvolvingTable.host(): EvolvingTable,
-    FamilyfoodOnTheTable.host(): FamilyfoodOnTheTable,
-    FeastingAtHome.host(): FeastingAtHome,
-    FifteenGram.host(): FifteenGram,
-    FitSlowCookerQueen.host(): FitSlowCookerQueen,
-    FortyAprons.host(): FortyAprons,
-    GlutenFreeOnAShoeString.host(): GlutenFreeOnAShoeString,
-    GourmetTraveller.host(): GourmetTraveller,
-    GrandFrais.host(): GrandFrais,
-    HealthyWithAChanceOfSprinkles.host(): HealthyWithAChanceOfSprinkles,
-    HeatherChristo.host(): HeatherChristo,
-    HungryHappens.host(): HungryHappens,
-    InBloomBakery.host(): InBloomBakery,
-    InGoodFlavor.host(): InGoodFlavor,
-    InspiredTaste.host(): InspiredTaste,
-    IrishCentral.host(): IrishCentral,
-    JoCooks.host(): JoCooks,
-    JoshuaWeissman.host(): JoshuaWeissman,
-    JoyTheBaker.host(): JoyTheBaker,
-    Jumbo.host(): Jumbo,
-    KaleJunkie.host(): KaleJunkie,
-    KellysCleanKitchen.host(): KellysCleanKitchen,
-    KitchenAidAustralia.host(): KitchenAidAustralia,
-    KitchenDivas.host(): KitchenDivas,
-    KitchenDreaming.host(): KitchenDreaming,
-    KookJij.host(): KookJij,
-    KristinesKitchenBlog.host(): KristinesKitchenBlog,
-    KrollsKorner.host(): KrollsKorner,
-    KuchynaLidla.host(): KuchynaLidla,
-    LaCucinaItaliana.host(): LaCucinaItaliana,
-    LaCucinaItaliana.host(domain="com"): LaCucinaItaliana,
-    LanasCooking.host(): LanasCooking,
-    LittleSunnyKitchen.host(): LittleSunnyKitchen,
-    LeitesCulinaria.host(): LeitesCulinaria,
-    LoveAndLemons.host(): LoveAndLemons,
-    MadameCuisine.host(): MadameCuisine,
-    MakeItDairyFree.host(): MakeItDairyFree,
-    McCormick.host(): McCormick,
-    MealPrepManual.host(): MealPrepManual,
-    MeganVsKitchen.host(): MeganVsKitchen,
-    Miljuschka.host(): Miljuschka,
-    ModernHoney.host(): ModernHoney,
-    MomOnTimeout.host(): MomOnTimeout,
-    Moulinex.host(): Moulinex,
-    MundoDeReceitasBimby.host(): MundoDeReceitasBimby,
-    MyJewishLearning.host(): MyJewishLearning,
-    MyKoreanKitchen.host(): MyKoreanKitchen,
-    MyVegetarianRoots.host(): MyVegetarianRoots,
-    NatashasKitchen.host(): NatashasKitchen,
-    Ndr.host(): Ndr,
-    NoraCooks.host(): NoraCooks,
-    NotEnoughCinnamon.host(): NotEnoughCinnamon,
-    NutritionFacts.host(): NutritionFacts,
-    OkokoRecepten.host(): OkokoRecepten,
-    OneSweetAppetite.host(): OneSweetAppetite,
-    OrganicallyAddison.host(): OrganicallyAddison,
-    OttolenghiBooks.host(): OttolenghiBooks,
-    PeelWithZeal.host(): PeelWithZeal,
-    PinchOfYum.host(): PinchOfYum,
-    PotatoRolls.host(): PotatoRolls,
-    PreppyKitchen.host(): PreppyKitchen,
-    QuiToque.host(): QuiToque,
-    Recept.host(): Recept,
-    ReceptyPreVas.host(): ReceptyPreVas,
-    RecettePlus.host(): RecettePlus,
-    RecipeGirl.host(): RecipeGirl,
-    Rewe.host(): Rewe,
-    RecipeLand.host(): RecipeLand,
-    RicettePerBimby.host(): RicettePerBimby,
-    SamsungFood.host(): SamsungFood,
-    SandwhichTribunal.host(): SandwhichTribunal,
-    SavoryNothings.host(): SavoryNothings,
-    SheLikesFood.host(): SheLikesFood,
-    SimpleGreenSmoothies.host(): SimpleGreenSmoothies,
-    SizzleFish.host(): SizzleFish,
-    SpainOnAFork.host(): SpainOnAFork,
-    SpisBedre.host(): SpisBedre,
-    StacyLing.host(): StacyLing,
-    StrongrFastr.host(): StrongrFastr,
-    SudachiRecipes.host(): SudachiRecipes,
-    SugarHero.host(): SugarHero,
-    SwissMilk.host(): SwissMilk,
-    TasteAtlas.host(): TasteAtlas,
-    TastingHistory.host(): TastingHistory,
-    TastyOven.host(): TastyOven,
-    TheBigMansWorld.host(): TheBigMansWorld,
-    TheCookieRookie.host(): TheCookieRookie,
-    TheCookingGuy.host(): TheCookingGuy,
-    TheFoodieTakesFlight.host(): TheFoodieTakesFlight,
-    TheGlutenFreeAustrian.host(): TheGlutenFreeAustrian,
-    TheLoopyWhisk.host(): TheLoopyWhisk,
-    TheMediterraneDish.host(): TheMediterraneDish,
-    ThePalatableLife.host(): ThePalatableLife,
-    ThePlantBasedSchool.host(): ThePlantBasedSchool,
-    TheSaltyMarshmallow.host(): TheSaltyMarshmallow,
-    Thinlicious.host(): Thinlicious,
-    DomesticateMe.host(): DomesticateMe,
-    Downshiftology.host(): Downshiftology,
-    Dr.host(): Dr,
-    EatWell101.host(): EatWell101,
-    EatWhatTonight.host(): EatWhatTonight,
-    EatingBirdFood.host(): EatingBirdFood,
-    EatingWell.host(): EatingWell,
-    Eatsmarter.host(): Eatsmarter,
-    Eatsmarter.host(domain="de"): Eatsmarter,
-    EatTolerant.host(): EatTolerant,
     EmmiKochtEinfach.host(): EmmiKochtEinfach,
     Epicurious.host(): Epicurious,
+    ErinLivesWhole.host(): ErinLivesWhole,
     ErrensKitchen.host(): ErrensKitchen,
     EthanChlebowski.host(): EthanChlebowski,
+    EverydayPie.host(): EverydayPie,
+    EvolvingTable.host(): EvolvingTable,
+    FamilyfoodOnTheTable.host(): FamilyfoodOnTheTable,
     FarmhouseDelivery.host(): FarmhouseDelivery,
     FarmhouseOnBoone.host(): FarmhouseOnBoone,
     FattoInCasaDaBenedetta.host(): FattoInCasaDaBenedetta,
+    FeastingAtHome.host(): FeastingAtHome,
     FelixKitchen.host(): FelixKitchen,
     Festligare.host(): Festligare,
+    FifteenGram.host(): FifteenGram,
     FifteenSpatulas.host(): FifteenSpatulas,
     FineDiningLovers.host(): FineDiningLovers,
     FitMenCook.host(): FitMenCook,
+    FitSlowCookerQueen.host(): FitSlowCookerQueen,
     Food.host(): Food,
     Food52.host(): Food52,
     FoodAndWine.host(): FoodAndWine,
@@ -724,26 +676,33 @@ SCRAPERS = {
     FoodNetwork.host(): FoodNetwork,
     FoodNetwork.host(domain="com"): FoodNetwork,
     FoodRepublic.host(): FoodRepublic,
-    ForkToSpoon.host(): ForkToSpoon,
     ForksOverKnives.host(): ForksOverKnives,
+    ForkToSpoon.host(): ForkToSpoon,
+    FortyAprons.host(): FortyAprons,
     FranzoesischKochen.host(): FranzoesischKochen,
     G750g.host(): G750g,
     GarnishAndGlaze.host(): GarnishAndGlaze,
+    GesundAktiv.host(): GesundAktiv,
     GialloZafferano.host(): GialloZafferano,
     GimmeSomeOven.host(): GimmeSomeOven,
     Globo.host(): Globo,
+    GlutenFreeOnAShoeString.host(): GlutenFreeOnAShoeString,
     Godt.host(): Godt,
     GonnaWantSeconds.host(): GonnaWantSeconds,
     GoodFoodDiscoveries.host(): GoodFoodDiscoveries,
     GoodHousekeeping.host(): GoodHousekeeping,
+    GourmetTraveller.host(): GourmetTraveller,
+    GrandFrais.host(): GrandFrais,
     GreatBritishChefs.host(): GreatBritishChefs,
     GrimGrains.host(): GrimGrains,
     GroupRecipes.host(): GroupRecipes,
-    HEB.host(): HEB,
     HalfBakedHarvest.host(): HalfBakedHarvest,
     HandleTheHeat.host(): HandleTheHeat,
     HassanChef.host(): HassanChef,
     HeadbangersKitchen.host(): HeadbangersKitchen,
+    HealthyWithAChanceOfSprinkles.host(): HealthyWithAChanceOfSprinkles,
+    HeatherChristo.host(): HeatherChristo,
+    HEB.host(): HEB,
     HelloFresh.host(): HelloFresh,
     HelloFresh.host(domain="at"): HelloFresh,
     HelloFresh.host(domain="be"): HelloFresh,
@@ -763,177 +722,288 @@ SCRAPERS = {
     HelloFresh.host(domain="no"): HelloFresh,
     HelloFresh.host(domain="se"): HelloFresh,
     HersheyLand.host(): HersheyLand,
+    HilahCooking.host(): HilahCooking,
     Hofer.host(): Hofer,
     Hofer.host(domain="hofer.si"): Hofer,
+    HomeAndPlate.host(): HomeAndPlate,
     HomeChef.host(): HomeChef,
     Hostthetoast.host(): Hostthetoast,
+    HowToFeedALoon.host(): HowToFeedALoon,
+    HungryHappens.host(): HungryHappens,
     Ica.host(): Ica,
-    ImWorthy.host(): ImWorthy,
     IG.host(): IG,
+    ImWorthy.host(): ImWorthy,
+    InBloomBakery.host(): InBloomBakery,
     IndianHealthyRecipes.host(): IndianHealthyRecipes,
+    InGoodFlavor.host(): InGoodFlavor,
     Innit.host(): Innit,
     InsanelyGoodRecipes.host(): InsanelyGoodRecipes,
     Inspiralized.host(): Inspiralized,
+    InspiredTaste.host(): InspiredTaste,
+    IowaGirlEats.host(): IowaGirlEats,
+    IrishCentral.host(): IrishCentral,
     IzzyCooking.host(): IzzyCooking,
     JamieOliver.host(): JamieOliver,
     JimCooksFoodGood.host(): JimCooksFoodGood,
+    JoCooks.host(): JoCooks,
+    JoshuaWeissman.host(): JoshuaWeissman,
     Joyfoodsunshine.host(): Joyfoodsunshine,
+    JoyTheBaker.host(): JoyTheBaker,
     JulieGoodwin.host(): JulieGoodwin,
+    Jumbo.host(): Jumbo,
+    JustALittleBitOfBacon.host(): JustALittleBitOfBacon,
     JustATaste.host(): JustATaste,
     JustBento.host(): JustBento,
+    JustineSnacks.host(): JustineSnacks,
     JustOneCookbook.host(): JustOneCookbook,
+    KaleJunkie.host(): KaleJunkie,
+    KellysCleanKitchen.host(): KellysCleanKitchen,
     KennyMcGovern.host(): KennyMcGovern,
     KeukenLiefdeNL.host(): KeukenLiefdeNL,
+    KiddoKitchen.host(): KiddoKitchen,
+    Kikkoman.host(): Kikkoman,
     KingArthur.host(): KingArthur,
-    KitchenStories.host(): KitchenStories,
+    KitchenAidAustralia.host(): KitchenAidAustralia,
+    KitchenDivas.host(): KitchenDivas,
+    KitchenDreaming.host(): KitchenDreaming,
     KitchenSanctuary.host(): KitchenSanctuary,
+    KitchenStories.host(): KitchenStories,
     Kochbar.host(): Kochbar,
     Kochbucher.host(): Kochbucher,
     Koket.host(): Koket,
+    KookJij.host(): KookJij,
+    KristinesKitchenBlog.host(): KristinesKitchenBlog,
+    KrollsKorner.host(): KrollsKorner,
     KuchniaDomowa.host(): KuchniaDomowa,
+    KuchynaLidla.host(): KuchynaLidla,
     KwestiaSmaku.host(): KwestiaSmaku,
+    LaCucinaItaliana.host(): LaCucinaItaliana,
+    LaCucinaItaliana.host(domain="com"): LaCucinaItaliana,
+    LanasCooking.host(): LanasCooking,
     LAtelierDeRoxane.host(): LAtelierDeRoxane,
-    LeCremeDeLaCrumb.host(): LeCremeDeLaCrumb,
     LeanAndGreenRecipes.host(): LeanAndGreenRecipes,
     Lecker.host(): Lecker,
+    LeckerSchmecker.host(): LeckerSchmecker,
+    LeCremeDeLaCrumb.host(): LeCremeDeLaCrumb,
+    LeitesCulinaria.host(): LeitesCulinaria,
     LekkerEnSimpel.host(): LekkerEnSimpel,
     Leukerecepten.host(): Leukerecepten,
     LifestyleOfAFoodie.host(): LifestyleOfAFoodie,
     LittleSpiceJar.host(): LittleSpiceJar,
+    LittleSunnyKitchen.host(): LittleSunnyKitchen,
     LivelyTable.host(): LivelyTable,
+    LoveAndLemons.host(): LoveAndLemons,
     Lovingitvegan.host(): Lovingitvegan,
     Maangchi.host(): Maangchi,
+    MadameCuisine.host(): MadameCuisine,
     MadensVerden.host(): MadensVerden,
     Madsvin.host(): Madsvin,
+    MakeItDairyFree.host(): MakeItDairyFree,
     Marmiton.host(): Marmiton,
     MarthaStewart.host(): MarthaStewart,
     Matprat.host(): Matprat,
+    McCormick.host(): McCormick,
+    MealPrepManual.host(): MealPrepManual,
+    MeganVsKitchen.host(): MeganVsKitchen,
     Meljoulwan.host(): Meljoulwan,
     MelsKitchenCafe.host(): MelsKitchenCafe,
+    Migusto.host(): Migusto,
+    Miljuschka.host(): Miljuschka,
     Mindmegette.host(): Mindmegette,
     Minimalistbaker.host(): Minimalistbaker,
     MinistryOfCurry.host(): MinistryOfCurry,
     Misya.host(): Misya,
     Mob.host(): Mob,
     MobKitchen.host(): MobKitchen,
+    ModernHoney.host(): ModernHoney,
+    MomOnTimeout.host(): MomOnTimeout,
     MomsWithCrockPots.host(): MomsWithCrockPots,
     MotherThyme.host(): MotherThyme,
+    Moulinex.host(): Moulinex,
+    MundoDeReceitasBimby.host(): MundoDeReceitasBimby,
     MyBakingAddiction.host(): MyBakingAddiction,
+    MyJewishLearning.host(): MyJewishLearning,
     MyKitchen101.host(): MyKitchen101,
     MyKitchen101en.host(): MyKitchen101en,
+    MyKoreanKitchen.host(): MyKoreanKitchen,
     MyRecipes.host(): MyRecipes,
-    NRKMat.host(): NRKMat,
-    NibbleDish.host(): NibbleDish,
+    MyVegetarianRoots.host(): MyVegetarianRoots,
+    NatashasKitchen.host(): NatashasKitchen,
+    NaturallyElla.host(): NaturallyElla,
+    Ndr.host(): Ndr,
+    NetaCooks.host(): NetaCooks,
     NHSHealthierFamilies.host(): NHSHealthierFamilies,
+    NibbleDish.host(): NibbleDish,
     NIHHealthyEating.host(): NIHHealthyEating,
-    NYTimes.host(): NYTimes,
+    NinjaTestKitchen.host(): NinjaTestKitchen,
+    NoraCooks.host(): NoraCooks,
     NoRecipes.host(): NoRecipes,
     NoSalty.host(): NoSalty,
+    NotEnoughCinnamon.host(): NotEnoughCinnamon,
     NourishedByNutrition.host(): NourishedByNutrition,
+    NRKMat.host(): NRKMat,
     Number2Pencil.host(): Number2Pencil,
     NutritionByNathalie.host(): NutritionByNathalie,
+    NutritionFacts.host(): NutritionFacts,
+    NYTimes.host(): NYTimes,
     OhSheGlows.host(): OhSheGlows,
+    OkokoRecepten.host(): OkokoRecepten,
     OmnivoresCookbook.host(): OmnivoresCookbook,
     OnceUponAChef.host(): OnceUponAChef,
     OneHundredOneCookBooks.host(): OneHundredOneCookBooks,
+    OneSweetAppetite.host(): OneSweetAppetite,
+    OrganicallyAddison.host(): OrganicallyAddison,
+    OttolenghiBooks.host(): OttolenghiBooks,
     OwenHan.host(): OwenHan,
     PaleoRunningMomma.host(): PaleoRunningMomma,
     Panelinha.host(): Panelinha,
     PaniniHappy.host(): PaniniHappy,
+    PanlasangPinoy.host(): PanlasangPinoy,
+    PeelWithZeal.host(): PeelWithZeal,
     PersnicketyPlates.host(): PersnicketyPlates,
-    Picnic.host(): Picnic,
     PickUpLimes.host(): PickUpLimes,
+    Picnic.host(): Picnic,
+    PilipinasRecipes.host(): PilipinasRecipes,
+    PinchOfYum.host(): PinchOfYum,
     PingoDoce.host(): PingoDoce,
     PinkOwlKitchen.host(): PinkOwlKitchen,
     PlatingPixels.host(): PlatingPixels,
     PlowingThroughLife.host(): PlowingThroughLife,
+    PoppyCooks.host(): PoppyCooks,
     PopSugar.host(): PopSugar,
+    PotatoRolls.host(): PotatoRolls,
     PracticalSelfReliance.host(): PracticalSelfReliance,
+    PreppyKitchen.host(): PreppyKitchen,
     PressureLuckCooking.host(): PressureLuckCooking,
     PrimalEdgeHealth.host(): PrimalEdgeHealth,
     ProjectGezond.host(): ProjectGezond,
     Przepisy.host(): Przepisy,
     PurelyPope.host(): PurelyPope,
     PurpleCarrot.host(): PurpleCarrot,
+    QuakerOats.host(): QuakerOats,
+    QuiToque.host(): QuiToque,
     RachlMansfield.host(): RachlMansfield,
     RainbowPlantLife.host(): RainbowPlantLife,
     RealFoodTesco.host(): RealFoodTesco,
+    RealFoodWell.host(): RealFoodWell,
     RealSimple.host(): RealSimple,
-    RealFoodTesco.host(): RealFoodTesco,
     ReceitasNestleBR.host(): ReceitasNestleBR,
+    Recept.host(): Recept,
+    ReceptyPreVas.host(): ReceptyPreVas,
+    RecettePlus.host(): RecettePlus,
+    RecipeGirl.host(): RecipeGirl,
+    RecipeLand.host(): RecipeLand,
     RecipeRunner.host(): RecipeRunner,
     RecipeTinEats.host(): RecipeTinEats,
     RedHouseSpice.host(): RedHouseSpice,
     Reishunger.host(): Reishunger,
+    Rewe.host(): Rewe,
     Rezeptwelt.host(): Rezeptwelt,
     Ricetta.host(): Ricetta,
+    RicettePerBimby.host(): RicettePerBimby,
     RosannaPansino.host(): RosannaPansino,
     RutgerBakt.host(): RutgerBakt,
     SaboresAjinomoto.host(): SaboresAjinomoto,
     SallysBakingAddiction.host(): SallysBakingAddiction,
     SallysBlog.host(): SallysBlog,
     SaltPepperSkillet.host(): SaltPepperSkillet,
+    SamsungFood.host(): SamsungFood,
+    SandwhichTribunal.host(): SandwhichTribunal,
     Saveur.host(): Saveur,
+    SavoryNothings.host(): SavoryNothings,
     SchoolOfWok.host(): SchoolOfWok,
+    ScrummyLane.host(): ScrummyLane,
     SeriousEats.host(): SeriousEats,
+    SheLikesFood.host(): SheLikesFood,
+    SimpleGreenSmoothies.host(): SimpleGreenSmoothies,
     SimpleVeganista.host(): SimpleVeganista,
     SimplyCookit.host(): SimplyCookit,
     SimplyQuinoa.host(): SimplyQuinoa,
     SimplyRecipes.host(): SimplyRecipes,
     SimplyWhisked.host(): SimplyWhisked,
+    SizzleFish.host(): SizzleFish,
     SkinnyTaste.host(): SkinnyTaste,
     Smulweb.host(): Smulweb,
     SoBors.host(): SoBors,
     SouthernCastIron.host(): SouthernCastIron,
     SouthernLiving.host(): SouthernLiving,
+    SpainOnAFork.host(): SpainOnAFork,
     SpendWithPennies.host(): SpendWithPennies,
+    SpisBedre.host(): SpisBedre,
     Springlane.host(): Springlane,
+    StacyLing.host(): StacyLing,
     StaySnatched.host(): StaySnatched,
     SteamyKitchen.host(): SteamyKitchen,
     StreetKitchen.host(): StreetKitchen,
+    StrongrFastr.host(): StrongrFastr,
+    SudachiRecipes.host(): SudachiRecipes,
+    SugarHero.host(): SugarHero,
     SunBasket.host(): SunBasket,
     SundPaaBudget.host(): SundPaaBudget,
     Sunset.host(): Sunset,
     SweetCsDesigns.host(): SweetCsDesigns,
     SweetPeasAndSaffron.host(): SweetPeasAndSaffron,
+    SwissMilk.host(): SwissMilk,
+    TableAndDish.host(): TableAndDish,
+    TasteAtlas.host(): TasteAtlas,
     TasteAU.host(): TasteAU,
     TasteOfHome.host(): TasteOfHome,
     TastesBetterFromScratch.host(): TastesBetterFromScratch,
     TastesOfLizzyT.host(): TastesOfLizzyT,
+    TastingHistory.host(): TastingHistory,
     Tasty.host(): Tasty,
     TastyKitchen.host(): TastyKitchen,
+    TastyOven.host(): TastyOven,
+    TatyanasEverydayFood.host(): TatyanasEverydayFood,
+    TheBigMansWorld.host(): TheBigMansWorld,
     TheCleverCarrot.host(): TheCleverCarrot,
+    TheCookieRookie.host(): TheCookieRookie,
+    TheCookingGuy.host(): TheCookingGuy,
+    TheFirstMess.host(): TheFirstMess,
+    TheFoodieTakesFlight.host(): TheFoodieTakesFlight,
+    TheGlutenFreeAustrian.host(): TheGlutenFreeAustrian,
     TheHappyFoodie.host(): TheHappyFoodie,
     TheKitchenCommunity.host(): TheKitchenCommunity,
     TheKitchenMagPie.host(): TheKitchenMagPie,
     TheKitchn.host(): TheKitchn,
+    TheLoopyWhisk.host(): TheLoopyWhisk,
     TheMagicalSlowCooker.host(): TheMagicalSlowCooker,
+    TheMediterraneDish.host(): TheMediterraneDish,
     TheModernProper.host(): TheModernProper,
+    TheOldWomanAndTheSea.host(): TheOldWomanAndTheSea,
+    ThePalatableLife.host(): ThePalatableLife,
     ThePioneerWoman.host(): ThePioneerWoman,
+    ThePlantBasedSchool.host(): ThePlantBasedSchool,
+    TheRecipeCritic.host(): TheRecipeCritic,
+    TheSaltyMarshmallow.host(): TheSaltyMarshmallow,
+    TheSpiceTrain.host(): TheSpiceTrain,
     TheSpruceEats.host(): TheSpruceEats,
     TheVintageMixer.host(): TheVintageMixer,
-    TheRecipeCritic.host(): TheRecipeCritic,
     Thewoksoflife.host(): Thewoksoflife,
+    Thinlicious.host(): Thinlicious,
+    ThisHealthyTable.host(): ThisHealthyTable,
     TidyMom.host(): TidyMom,
     TimesOfIndia.host(): TimesOfIndia,
     TineNo.host(): TineNo,
     Tofoo.host(): Tofoo,
+    ToriAvey.host(): ToriAvey,
     TudoGostoso.host(): TudoGostoso,
     TwentyFourKitchen.host(): TwentyFourKitchen,
     TwoPeasAndTheirPod.host(): TwoPeasAndTheirPod,
+    UitPaulinesKeukenNL.host(): UitPaulinesKeukenNL,
+    Unsophisticook.host(): Unsophisticook,
     USAPears.host(): USAPears,
     USDAMyPlate.host(): USDAMyPlate,
-    Unsophisticook.host(): Unsophisticook,
     Valdemarsro.host(): Valdemarsro,
     VanillaAndBean.host(): VanillaAndBean,
     VarechaPravdaSK.host(): VarechaPravdaSK,
-    VegRecipesOfIndia.host(): VegRecipesOfIndia,
     Vegetarbloggen.host(): Vegetarbloggen,
     Vegolosi.host(): Vegolosi,
+    VegRecipesOfIndia.host(): VegRecipesOfIndia,
     VeroniqueCloutier.host(): VeroniqueCloutier,
-    WDR.host(): WDR,
     Waitrose.host(): Waitrose,
     WatchWhatUEat.host(): WatchWhatUEat,
+    WDR.host(): WDR,
     WeAreNotMartha.host(): WeAreNotMartha,
     WeDishItUp.host(): WeDishItUp,
     WeightWatchers.host(): WeightWatchers,
@@ -943,17 +1013,16 @@ SCRAPERS = {
     Whole30.host(): Whole30,
     WholeFoods.host(): WholeFoods,
     WholeFoods.host(domain="co.uk"): WholeFoods,
+    WikiCookbook.host(): WikiCookbook,
     WilliamsSonoma.host(): WilliamsSonoma,
     WomensWeeklyFood.host(): WomensWeeklyFood,
     Woop.host(): Woop,
-    WikiCookbook.host(): WikiCookbook,
+    Xiachufang.host(): Xiachufang,
     Yemek.host(): Yemek,
     Yummly.host(): Yummly,
     ZauberTopf.host(): ZauberTopf,
     ZeitWochenmarkt.host(): ZeitWochenmarkt,
     ZenBelly.host(): ZenBelly,
-    GesundAktiv.host(): GesundAktiv,
-    UitPaulinesKeukenNL.host(): UitPaulinesKeukenNL,
     ZestfulKitchen.host(): ZestfulKitchen,
 }
 
