@@ -8,12 +8,9 @@ class ABeautifulMess(AbstractScraper):
         return "abeautifulmess.com"
 
     def equipment(self):
-        equipment_container = self.soup.select_one(".wprm-recipe-equipment-container")
-        if not equipment_container:
-            return None
-
         equipment_items = [
-            item.get_text()
-            for item in equipment_container.select(".wprm-recipe-equipment-name")
+            text
+            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
+            if (text := equip.get_text())
         ]
         return get_equipment(equipment_items)
