@@ -1,5 +1,4 @@
 from ._abstract import AbstractScraper
-from ._grouping_utils import group_ingredients
 
 
 class DomesticateMe(AbstractScraper):
@@ -15,11 +14,3 @@ class DomesticateMe(AbstractScraper):
         author_meta_tag = self.soup.find("meta", {"name": "author"})
         author_name = author_meta_tag["content"] if author_meta_tag else None
         return author_name
-
-    def ingredient_groups(self):
-        return group_ingredients(
-            self.ingredients(),
-            self.soup,
-            ".wprm-recipe-ingredient-group h4",
-            ".wprm-recipe-ingredient-group li",
-        )
