@@ -9,8 +9,8 @@ class GlutenFreeOnAShoeString(AbstractScraper):
 
     def equipment(self):
         equipment_items = [
-            equip.get_text()
+            text
             for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if equip.get_text()
+            if (text := equip.get_text())
         ]
         return get_equipment(equipment_items)
