@@ -9,8 +9,8 @@ class MomsWithCrockPots(AbstractScraper):
 
     def equipment(self):
         equipment_items = [
-            item.find("a", class_="wprm-recipe-equipment-link").get_text()
-            for item in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if item.find("a", class_="wprm-recipe-equipment-link")
+            text
+            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
+            if (text := equip.get_text())
         ]
         return get_equipment(equipment_items)
