@@ -9,3 +9,9 @@ class PingoDoce(AbstractScraper):
     def instructions(self):
         instructions = self.soup.findAll("div", {"class": "step-description"})
         return "\n".join([i.get_text() for i in instructions])
+
+    def category(self):
+        return None
+
+    def cuisine(self):
+        return None
