@@ -1,6 +1,5 @@
-# mypy: allow-untyped-defs
-
 from ._abstract import AbstractScraper
+from ._exceptions import StaticValueException
 from ._utils import get_yields, normalize_string
 
 
@@ -9,6 +8,9 @@ class Przepisy(AbstractScraper):
     def host(cls):
         return "przepisy.pl"
 
+    def site_name(self):
+        raise StaticValueException(return_value="Przepisy.pl")
+
     def yields(self):
         return get_yields(self.soup.find("div", {"class": "person-count"}))
 
