@@ -11,15 +11,9 @@ class SaltPepperSkillet(AbstractScraper):
         return self.schema.author().title()
 
     def equipment(self):
-        equipment_container = self.soup.find(
-            "div", class_="wprm-recipe-equipment-container"
-        )
-        if not equipment_container:
-            return None
         equipment_items = [
-            item.get_text(strip=True)
-            for item in equipment_container.find_all(
-                "div", class_="wprm-recipe-equipment-name"
-            )
+            text
+            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
+            if (text := equip.get_text())
         ]
         return get_equipment(equipment_items)
