@@ -1,3 +1,4 @@
+import functools
 from ._abstract import AbstractScraper
 from ._utils import normalize_string
 
@@ -10,6 +11,7 @@ class SunBasket(AbstractScraper):
     def site_name(self):
         return self.author()
 
+    @functools.cached_property
     def _instructions_list(self):
         instructions_container = self.soup.find(
             "div", {"class": "instructions-container"}
@@ -34,5 +36,5 @@ class SunBasket(AbstractScraper):
         return instruction_list
 
     def instructions(self):
-        data = self._instructions_list()
+        data = self._instructions_list
         return "\n".join(data) if data else None
