@@ -1,4 +1,5 @@
 from ._abstract import AbstractScraper
+from ._utils import get_equipment
 
 
 class WatchWhatUEat(AbstractScraper):
@@ -18,3 +19,11 @@ class WatchWhatUEat(AbstractScraper):
             text = " ".join(part.get_text(strip=True) for part in parts)
             ingredients.append(text.strip())
         return ingredients
+
+    def equipment(self):
+        equipment_items = [
+            text
+            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
+            if (text := equip.get_text())
+        ]
+        return get_equipment(equipment_items)
